# SEC06-BP05: Enable people to perform actions at a distance

## Description

Avoid direct SSH access.

## Implementation Guidance

- Session Manager for access
- Bastion-less architecture
- Just-in-time access
- Audit all access
- No persistent credentials on hosts

## Risk Level

High - Direct SSH access is an attack vector.
